@@ -85,7 +85,7 @@ CMD = "ml"  # The command line tool.
 EXT_MLM = ".mlm"  # Archive filename extension
 EXT_AIPK = ".aipk"  # Backward compatibility
 
-VERSION = "3.9.1"  # DO NOT MODIFY. Managed from ../Makefile.
+VERSION = "3.9.3"  # DO NOT MODIFY. Managed from ../Makefile.
 
 OPTIONS = {
     # Global command line options
@@ -93,7 +93,6 @@ OPTIONS = {
     # All the keys in dict correspond to the keyword arguments of
     # 'argparse.ArgumentParser.add_argument()'.
     "--version": {
-        "alias": ["-v"],
         "help": "display version information of ml or a package and exit.",
         "action": "store_true",
     },
@@ -240,6 +239,14 @@ COMMANDS = {
         "func": "remove_model",
         "next": ["installed", "install"],
     },
+    "version": {
+        "description": "display version information of ml or a package and exit.",
+        "argument": {
+            "model": {"nargs": "?"},
+        },
+        "usage": "  version     <model>   display version information",
+        "func": "check_version",
+    },
     # 'demo': {
     #     'description': "run the model's demonstration",
     #     'alias': ['print', 'display', 'score', 'rebuild'],
